@@ -528,7 +528,7 @@ def mds_torch(pre_dist_mat, weights=None, iters=10, tol=1e-5, verbose=2):
     # start
     batch, N, _ = pre_dist_mat.shape
     diag_idxs = np.arange(N)
-    his = [torch.tensor([np.inf]*batch)]
+    his = [torch.tensor([np.inf]*batch, device=device)]
     # init random coords
     best_stress = float("Inf") * torch.ones(batch, device = device).type(dtype)
     best_3d_coords = 2*torch.rand(batch, N, 3, device = device).type(dtype) - 1
